@@ -1,6 +1,11 @@
-from typing import Any, cast, override
+from typing import Any, cast
 from uuid import UUID
 
+try:
+    from typing import override
+except ImportError:  # pragma: no cover
+    from typing_extensions import override
+
 from django.core.exceptions import ValidationError
 from django.db import models
 from django.db.backends.base.base import BaseDatabaseWrapper
@@ -20,9 +25,9 @@ class ULIDField(models.UUIDField):  # type: ignore[type-arg]
     - https://github.com/mdomke/python-ulid
     """
 
-    _pyi_private_set_type: str | ULID  # type: ignore[assignment]
+    _pyi_private_set_type: ULID | UUID | str | int  # type: ignore[assignment]
     _pyi_private_get_type: ULID  # type: ignore[assignment]
-    _pyi_lookup_exact_type: ULID | str  # type: ignore[assignment]
+    _pyi_lookup_exact_type: ULID | UUID | str | int  # type: ignore[assignment]
 
     description = _("Universally unique lexicographically sortable identifier")
 
@@ -32,10 +37,10 @@ class ULIDField(models.UUIDField):  # type: ignore[type-arg]
             return value
         try:
             if isinstance(value, str) and len(value) == 26:
-                return cast(ULID, ULID.from_str(value))
+                return ULID.from_str(value)
             else:
                 value = super().to_python(value)
-                return cast(ULID, ULID.from_uuid(value))
+                return ULID.from_uuid(value)
         except (ValueError, ValidationError) as err:
             raise ValidationError(
                 _("%(value)r is not a valid ULID."),
